#[non_exhaustive]pub enum EmailParseError {
InvalidDisplayFormat,
InvalidCharacters {
character_set: String,
},
InvalidEscapeSequence {
sequence: String,
},
MissingDomain,
MissingLocalPart,
LocalPartLengthExceeded {
length: usize,
max_length: usize,
},
DomainParseError(DomainParseError),
}Expand description
Represents errors that can occur during email address parsing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidDisplayFormat
The display name format is invalid.
InvalidCharacters
The email address contains characters that are not allowed.
InvalidEscapeSequence
The email address contains an invalid escape sequence.
MissingDomain
The email address is missing a domain.
MissingLocalPart
The email address is missing a local part.
LocalPartLengthExceeded
The local part of the email address exceeds the maximum allowed length.
DomainParseError(DomainParseError)
The domain part of the email address fails to parse.